atan2pi_big_exp_difference_hard

Function atan2pi_big_exp_difference_hard 

fn atan2pi_big_exp_difference_hard(
    num: f64,
    den: f64,
    x_sign: usize,
    y_sign: usize,
    recip: bool,
    final_sign: f64,
) -> f64
If one of arguments is too huge or too small, extended precision is required for case with big exponent difference